aboutsummaryrefslogtreecommitdiffstats
path: root/testing/irrlicht/irrlicht-1.8.1-config.patch
diff options
context:
space:
mode:
Diffstat (limited to 'testing/irrlicht/irrlicht-1.8.1-config.patch')
-rw-r--r--testing/irrlicht/irrlicht-1.8.1-config.patch56
1 files changed, 29 insertions, 27 deletions
diff --git a/testing/irrlicht/irrlicht-1.8.1-config.patch b/testing/irrlicht/irrlicht-1.8.1-config.patch
index a394dc14d2..b1b8b74201 100644
--- a/testing/irrlicht/irrlicht-1.8.1-config.patch
+++ b/testing/irrlicht/irrlicht-1.8.1-config.patch
@@ -1,29 +1,31 @@
+diff --git a/include/IrrCompileConfig.h b/include/IrrCompileConfig.h
+index 2fa2423..e0bff92 100644
--- a/include/IrrCompileConfig.h
+++ b/include/IrrCompileConfig.h
-@@ -249,7 +249,7 @@
- //! Define _IRR_USE_NON_SYSTEM_JPEG_LIB_ to let irrlicht use the jpeglib which comes with irrlicht.
- /** If this is commented out, Irrlicht will try to compile using the jpeg lib installed in the system.
- This is only used when _IRR_COMPILE_WITH_LIBJPEG_ is defined. */
--#define _IRR_USE_NON_SYSTEM_JPEG_LIB_
-+//#define _IRR_USE_NON_SYSTEM_JPEG_LIB_
- #ifdef NO_IRR_USE_NON_SYSTEM_JPEG_LIB_
- #undef _IRR_USE_NON_SYSTEM_JPEG_LIB_
- #endif
-@@ -265,7 +265,7 @@
- //! Define _IRR_USE_NON_SYSTEM_LIBPNG_ to let irrlicht use the libpng which comes with irrlicht.
- /** If this is commented out, Irrlicht will try to compile using the libpng installed in the system.
- This is only used when _IRR_COMPILE_WITH_LIBPNG_ is defined. */
--#define _IRR_USE_NON_SYSTEM_LIB_PNG_
-+//#define _IRR_USE_NON_SYSTEM_LIB_PNG_
- #ifdef NO_IRR_USE_NON_SYSTEM_LIB_PNG_
- #undef _IRR_USE_NON_SYSTEM_LIB_PNG_
- #endif
-@@ -602,7 +602,7 @@
- /** If this is commented out, Irrlicht will try to compile using the zlib
- installed on the system. This is only used when _IRR_COMPILE_WITH_ZLIB_ is
- defined. */
--#define _IRR_USE_NON_SYSTEM_ZLIB_
-+//#define _IRR_USE_NON_SYSTEM_ZLIB_
- #ifdef NO_IRR_USE_NON_SYSTEM_ZLIB_
- #undef _IRR_USE_NON_SYSTEM_ZLIB_
- #endif
+@@ -249,7 +249,7 @@ the engine will no longer read .jpeg images. */
+ //! Define _IRR_USE_NON_SYSTEM_JPEG_LIB_ to let irrlicht use the jpeglib which comes with irrlicht.
+ /** If this is commented out, Irrlicht will try to compile using the jpeg lib installed in the system.
+ This is only used when _IRR_COMPILE_WITH_LIBJPEG_ is defined. */
+-#define _IRR_USE_NON_SYSTEM_JPEG_LIB_
++//#define _IRR_USE_NON_SYSTEM_JPEG_LIB_
+ #ifdef NO_IRR_USE_NON_SYSTEM_JPEG_LIB_
+ #undef _IRR_USE_NON_SYSTEM_JPEG_LIB_
+ #endif
+@@ -265,7 +265,7 @@ the engine will no longer read .png images. */
+ //! Define _IRR_USE_NON_SYSTEM_LIBPNG_ to let irrlicht use the libpng which comes with irrlicht.
+ /** If this is commented out, Irrlicht will try to compile using the libpng installed in the system.
+ This is only used when _IRR_COMPILE_WITH_LIBPNG_ is defined. */
+-#define _IRR_USE_NON_SYSTEM_LIB_PNG_
++//#define _IRR_USE_NON_SYSTEM_LIB_PNG_
+ #ifdef NO_IRR_USE_NON_SYSTEM_LIB_PNG_
+ #undef _IRR_USE_NON_SYSTEM_LIB_PNG_
+ #endif
+@@ -594,7 +594,7 @@ B3D, MS3D or X meshes */
+ /** This enables the engine to read from compressed .zip archives. If you
+ disable this feature, the engine can still read archives, but only uncompressed
+ ones. */
+-#define _IRR_COMPILE_WITH_ZLIB_
++//#define _IRR_COMPILE_WITH_ZLIB_
+ #ifdef NO_IRR_COMPILE_WITH_ZLIB_
+ #undef _IRR_COMPILE_WITH_ZLIB_
+ #endif